.input-group-addon {
    right: 0;
    padding-right: 30px;
    padding-top: 10px;
    max-width: 40px;
    background-color: lightgrey;
    border: silver 1px solid;
}
.input-group-addon > a {
    font-size: 16px;
}